@@ -36,7 +36,6 @@ VALID_ANALYSIS_OPTIONS = [
     "all",
     "flake8",
     "mypy",
-    "pydocstyle",
 ]
 
 
@@ -52,10 +51,6 @@ class MypyError(StaticAnalysisError):
     """Problem occurred with mypy analysis."""
 
 
-class PydocstyleError(StaticAnalysisError):
-    """Problem occurred with pydocstyle anslysis."""
-
-
 def _run_flake8(source_path: pathlib.Path, venv_path: pathlib.Path) -> None:
     """
     Run flake8 analysis on the specified source directory.
@@ -98,28 +93,6 @@ def _run_mypy(source_path: pathlib.Path, venv_path: pathlib.Path) -> None:
     click.echo(click.style("mypy analysis completed", fg="green"))
 
 
-def _run_pydocstyle(source_path: pathlib.Path, venv_path: pathlib.Path) -> None:
-    """
-    Run pydocstyle analysis on the specified source directory.
-
-    Args:
-        source_path: Path to project source directory.
-        venv_path: Path to Python virtual environment.
-
-    Raises:
-        StaticAnalysisError: If pydocstyle analysis fails.
-    """
-    click.echo(
-        click.style(
-            "WARNING: pydocstyle analysis is deprecated and will be removed in "
-            "the next major release. Run flake8 analysis instead with "
-            "flake8-docstrings plugin",
-            fg="yellow",
-        )
-    )
-    _run_flake8(source_path, venv_path)
-
-
 def _apply_analysis(
     analysis_type: str, project_path: pathlib.Path, venv_path: pathlib.Path
 ) -> None:
@@ -135,15 +108,11 @@ def _apply_analysis(
     analysis_methods = {
         "flake8": _run_flake8,
         "mypy": _run_mypy,
-        "pydocstyle": _run_pydocstyle,
     }
     if analysis_type != "all":
         analysis_methods[analysis_type](project_path / source_dir, venv_path)
     else:
-        # exclude deprecated `pydocstyle` analysis from `all`
-        for this_method in [
-            y for x, y in analysis_methods.items() if x != "pydocstyle"
-        ]:
+        for this_method in [y for x, y in analysis_methods.items()]:
             this_method(project_path / source_dir, venv_path)
 
 
@@ -159,9 +128,9 @@ def static_analysis(ctx: click.Context, analysis: str) -> None:
     """
     Run suite of Python static analysis.
 
-    The suite currently comprises "flake8", "pydocstyle" and "mypy". Formatting
-    is run before the static analysis to eliminate formatting complaints from
-    static analysis tools.
+    The suite currently comprises "flake8" and "mypy". Formatting is run before
+    the static analysis to eliminate formatting complaints from static analysis
+    tools.
     """
     try:
         ctx.ensure_object(dict)
@@ -180,9 +149,6 @@ def static_analysis(ctx: click.Context, analysis: str) -> None:
     except MypyError as e:
         report_console_error(str(e))
         sys.exit(ExitState.MYPY_FAILED.value)
-    except PydocstyleError as e:
-        report_console_error(str(e))
-        sys.exit(ExitState.PYDOCSTYLE_FAILED.value)
     except Exception:
         message = "Unexpected error. Check log for details."
         log.exception(message)
