@@ -81,7 +81,8 @@ def bdd_acceptance_command(
       tests:     run acceptance tests.
     """
     try:
-        command_state: CommandState = ctx.obj
+        ctx.ensure_object(dict)
+        command_state: CommandState = ctx.obj["command_state"]
 
         if run_type == "snippets":
             _generate_snippets(command_state.venv_path)
