@@ -318,7 +318,8 @@ def install(
     If  virtual environment does not presently exist, one will be created.
     """
     try:
-        command_state: CommandState = ctx.obj
+        ctx.ensure_object(dict)
+        command_state: CommandState = ctx.obj["command_state"]
 
         project_dependencies = acquire_project_dependencies(
             command_state.project_path
