@@ -8,6 +8,8 @@
 #
 
 import logging
+import os
+import pathlib
 import subprocess
 import typing
 
@@ -15,6 +17,8 @@ log = logging.getLogger(__name__)
 
 CommandArgs = typing.List[str]
 
+PROJECT_DIRECTORY = pathlib.Path(os.path.curdir).absolute()
+
 
 def run_command(
     command: CommandArgs, **kwargs: typing.Any
@@ -47,6 +51,15 @@ def run_command_sequence(sequence: typing.List[str]) -> None:
         response = run_command(this_command.split())
 
 
+def _remove_file(this_path: str) -> None:
+    (PROJECT_DIRECTORY / this_path).unlink(missing_ok=True)
+
+
+def _remove_unused_files():
+    if "{{ cookiecutter.pipeline_provider }}" != "gitlabci":
+        _remove_file(".gitlab-ci.yml")
+
+
 def init_git(default_branch_name: str) -> None:
     """
     Initialize git repo in the new project directory.
@@ -62,7 +75,8 @@ def init_git(default_branch_name: str) -> None:
 
 def commit_initial_files() -> None:
     """Commit initial set of file from template to source control."""
-    # Generated files typically need reformatting to comply with PEP-8 formatting.
+    # Generated files typically need reformatting to comply with PEP-8
+    # formatting so apply formatting here.
     commands = [
         "{{ cookiecutter._venv_bin }}/build-harness install",
         "{{ cookiecutter._venv_bin }}/build-harness formatting",
@@ -70,12 +84,14 @@ def commit_initial_files() -> None:
         "git add .",
     ]
     run_command_sequence(commands)
-    # .split() is too crude for the whitespace containing argument here, so just use
-    # `run_command` directly.
+    # .split() is too crude for the whitespace containing argument here, so
+    # just use `run_command` directly.
     run_command(["git","commit", "-m", "Initial files from template"])
 
 
 def main() -> None:
+    _remove_unused_files()
+
     default_branch_name = "{{ cookiecutter.default_branch }}"
 
     init_git(default_branch_name)
